@@ -28,11 +28,11 @@ Then /^the file "([^"]*)" should not have the same inode or ctime as before$/ do
 end
 
 Then /^the git revision of module "([^"]*)" should be "([0-9a-f]*)"$/ do |module_name, rev|
-    cd("modules/#{module_name}")
-    cmd = "git rev-parse HEAD"
-    run_simple(cmd)
-    assert_exact_output(rev, output_from(cmd).strip)
-    cd("../..")
+    cd("modules/#{module_name}") do
+      cmd = "git rev-parse HEAD"
+      run_command_and_stop(cmd)
+      expect(last_command_started.output.strip).to eq(rev)
+    end
 end
 
 Given /^I wait for (\d+) seconds?$/ do |n|
