@@ -46,7 +46,7 @@ module Librarian
 
           specfile ||= Proc.new if block_given?
 
-          if specfile.kind_of?(Pathname) and !File.exists?(specfile)
+          if specfile.kind_of?(Pathname) and !File.exist?(specfile)
             debug { "Specfile #{specfile} not found, using defaults" } unless specfile.nil?
             receiver(target).run(specfile, &default_specfile)
           else
@@ -78,28 +78,11 @@ module Librarian
           super
         end
 
-        # implement the 'modulefile' syntax for Puppetfile
-        def modulefile
-          f = modulefile_path
-          raise Error, "Modulefile file does not exist: #{f}" unless File.exists?(f)
-          File.read(f).lines.each do |line|
-            regexp = /\s*dependency\s+('|")([^'"]+)\1\s*(?:,\s*('|")([^'"]+)\3)?/
-            regexp =~ line && mod($2, $4)
-          end
-        end
-
         # implement the 'metadata' syntax for Puppetfile
         def metadata
           f = working_path.join('metadata.json')
-          unless File.exists?(f)
-            msg = "Metadata file does not exist: #{f}"
-            # try modulefile, in case we don't have a Puppetfile and we are using the default template
-            if File.exists?(modulefile_path)
-              modulefile
-              return
-            else
-              raise Error, msg
-            end
+          unless File.exist?(f)
+            raise Error, "Metadata file does not exist: #{f}"
           end
           begin
             json = JSON.parse(File.read(f))
@@ -111,12 +94,6 @@ module Librarian
             mod(d['name'], d['version_requirement'])
           end
         end
-
-        private
-
-        def modulefile_path
-          working_path.join('Modulefile')
-        end
       end
     end
   end
